@@ -2,7 +2,7 @@ from oarepo_model_builder.invenio.invenio_base import InvenioBaseClassPythonBuil
 
 
 class ConftestBuilder(InvenioBaseClassPythonBuilder):
-    TYPE = "conftest"
+    TYPE = "invenio_tests_conftest"
     template = "conftest"
     MODULE = "tests.conftest"
 
